package com.community.huiju.common.hk;

import com.alibaba.fastjson.JSON;
import com.community.commom.hk.Digests;
import com.community.commom.hk.HttpClientSSLUtils;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.Map;

/**
 * 海康 API
 * @author weiximei
 */
@Slf4j
public class HKOpenApi {

    /**
     * 根据
     * 组织中心UUID集 ,第几页, 一页多少行
     *
     * 获取  监控点 数据列表
     * @return
     */
    public static String getMonitoryPoint(Map<String,Object> map){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_MONITORY_POINT;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",map.get("pageNo"));
        parMap.put("pageSize",map.get("pageSize"));
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("unitUuids",map.get("unitUuids"));
        String params =  JSON.toJSONString(parMap);
        log.info("获取 监控列表 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("获取 监控列表 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("获取监控列表失败!",e);
        }

        return data;
    }

    /**
     * 根据部门名称分页获取部门
     *      第几页, 一页多少行, 操作用户uuid
     * @param map
     * @return
     */
    public static String getDeptName(Map<String,Object> map){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_LIKE_DEPT_NAME;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",map.get("pageNo"));
        parMap.put("pageSize",map.get("pageSize"));
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("deptName",map.get("deptName"));
        String params =  JSON.toJSONString(parMap);
        log.info("根据部门名称分页获取部门 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("根据部门名称分页获取部门 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("根据部门名称分页获取部门失败!",e);
        }

        return data;
    }


    /**
     * 添加人员
     *
     *      比如 住户
     * @return
     */
    public static String getAddUser(Map<String,Object> map){
        Map<String,Object> parMap = Maps.newHashMap();
        String url = HKConstant.OPENAPI_IP_PORT_HTTP + HKConstant.ITF_LIKE_DEPT_NAME;
        //设置APPKEY
        parMap.put("appkey", HKConstant.APPKEY);
        //设置时间参数
        parMap.put("time", System.currentTimeMillis());
        parMap.put("pageNo",map.get("pageNo"));
        parMap.put("pageSize",map.get("pageSize"));
        parMap.put("opUserUuid",map.get("opUserUuid") == null?HKConstant.OP_USER_UUID:map.get("opUserUuid"));
        parMap.put("personNo",map.get("personNo"));
        parMap.put("personName",map.get("personName"));
        String params =  JSON.toJSONString(parMap);
        log.info("添加人员 请求参数：{}", params);
        String data = null;
        try {
            data = HttpClientSSLUtils.doPost(url + "?token=" + Digests.buildToken(url + "?" + params, params, HKConstant.SECRET), params);
            log.info("添加人员 请求返回结果：{}",data);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("添加人员失败!",e);
        }

        return data;
    }


    public static void main(String[] args) {
        Map<String,Object> parMap = Maps.newHashMap();
        parMap.put("pageNo",1);
        parMap.put("pageSize",100);
        parMap.put("opUserUuid",HKConstant.OP_USER_UUID);
        parMap.put("deptName","住户");
        String result = HKOpenApi.getDeptName(parMap);
        System.out.println(result);
    }
}
